@@ -25,7 +25,7 @@ def test_document_pattern():
 
     # make sure DocumentPattern is untouched
 
-    expected_pattern_snippet = "`name`的`goods`"
+    expected_pattern_snippet = "<name>的<goods>"
     result_pattern = str(dp)
 
     assert expected_pattern_snippet in result_pattern
