@@ -12,7 +12,7 @@ def test_read_markdown(datadir):
     # check if str match
     expected_str_snippet = [
         "this is [#1](order) corpus. xxx. yyy.",
-        "this is `entity` corpus",
+        "this is <entity> corpus",
         "this is #3 corpus. xxx. yyy.",
         "this is #4 corpus",
     ]
