@@ -12,12 +12,17 @@ from tokenizer_tools.tagset.offset.analysis.read_markdown import read_markdown
 class CorpusPattern(Corpus):
     @classmethod
     def create_from_corpus(cls, corpus: Corpus) -> "CorpusPattern":
-        pattern_set = set()
+        pattern_set = collections.defaultdict(list)
         for doc in corpus:
             pattern = ExpressPattern.convert_to_pattern(doc)
-            pattern_set.add(pattern)
+            pattern_set[pattern].append(doc)
 
-        return cls(pattern_set)
+        # add docs to doc pattern
+        for k, v in pattern_set.items():
+            for doc in v:
+                k.add_doc(doc)
+
+        return cls(set(pattern_set.keys()))
 
     def render(self, dictionary: Dict[str, List[str]]):
         doc_list = []
