@@ -3,14 +3,30 @@ import re
 from typing import List
 from urllib.parse import unquote
 
-import mistune
-
 from tokenizer_tools.tagset.offset.document import Document
 from tokenizer_tools.tagset.offset.analysis.document_pattern import DocumentPattern
 from tokenizer_tools.tagset.offset.analysis.entity_placeholder import EntityPlaceholder
 from tokenizer_tools.tagset.offset.span import Span
 from tokenizer_tools.tagset.offset.span_set import SpanSet
 
+from mistletoe import Document as CommonMarkDocument
+from mistletoe.block_token import Heading, List as BlockList, ListItem, Paragraph
+from mistletoe.span_token import RawText, Link, SpanToken, _token_types
+
+
+class EntityPlaceholderToken(SpanToken):
+    parse_group = 1
+    parse_inner = False
+    precedence = 5
+    pattern = re.compile(r"\< *(\w+?) *\>")
+
+    def __init__(self, match):
+        self.target = match.group(1)
+
+
+# registry for recognize <xx> tag
+_token_types.insert(6, EntityPlaceholderToken)
+
 
 def create_doc(
     token_list: List[str], span_info_list: List[dict], placeholder_list, **kwargs
@@ -48,42 +64,40 @@ def create_doc(
         return doc_pattern
 
 
-def read_markdown(data) -> List[Document]:
-    doc_parser = mistune.create_markdown(renderer=mistune.AstRenderer())
-    doc = doc_parser(data)
+def read_markdown(data: str) -> List[Document]:
+    doc = CommonMarkDocument(data)
 
     doc_list = []
 
     current_intent = None
-    for top_item in doc:
-        if top_item["type"] == "heading":  # this is a head
-            # assert top_item["level"] == 1
-            current_intent = top_item["children"][0]["text"]
-        elif top_item["type"] == "list":  # this is ner list
-            for sub_item in top_item["children"]:  # sub item in list
-                assert sub_item["type"] == "list_item"
+    for top_item in doc.children:
+        if isinstance(top_item, Heading):  # this is a head
+            # assert top_item.level == 1
+            current_intent = top_item.content
+        elif isinstance(top_item, BlockList):  # this is ner list
+            for sub_item in top_item.children:  # sub item in list
+                assert isinstance(sub_item, ListItem)
+                assert sub_item.leader == "*"
 
                 token_list = []
                 span_list = []
                 placeholder_list = []
 
-                for element in sub_item["children"]:
-                    assert element["type"] == "block_text"
-
-                    for span_set in element["children"]:
-                        if span_set["type"] == "text":  # plain text
-                            partial_token_list = list(span_set["text"])
+                for element in sub_item.children:
+                    assert isinstance(element, Paragraph)
+                    for span_set in element.children:
+                        if isinstance(span_set, RawText):  # plain text
+                            partial_token_list = list(span_set.content)
                             token_list.extend(partial_token_list)
 
-                        elif span_set["type"] == "link":
-                            entity_type = unquote(span_set["link"])
+                        elif isinstance(span_set, Link):
+                            entity_type = span_set.target
 
-                            assert len(span_set["children"]) == 1
+                            assert len(span_set.children) == 1
 
-                            assert span_set["children"][0]["type"] == "text"
-                            entity_value = span_set["children"][0]["text"]
+                            entity_value = span_set.children[0].content
 
-                            partial_token_list = list(entity_value)
+                            partial_token_list = entity_value.split()
 
                             start_index = len(token_list)
 
@@ -97,8 +111,8 @@ def read_markdown(data) -> List[Document]:
 
                             token_list.extend(partial_token_list)
 
-                        elif span_set["type"] == "codespan":
-                            entity_placeholder = span_set["text"]
+                        elif isinstance(span_set, EntityPlaceholderToken):
+                            entity_placeholder = span_set.target
 
                             placeholder_list.append(
                                 {
