@@ -4,7 +4,7 @@ import numpy as np
 from sklearn.model_selection import train_test_split
 from fuzzywuzzy import process
 
-from tokenizer_tools.conllz.reader import read_conllx
+from tokenizer_tools.conllz.reader import load_conllx
 from tokenizer_tools.tagset.NER.BILUO import BILUOEncoderDecoder
 from tokenizer_tools.conllz.writer import write_conllx
 from tokenizer_tools.converter.conllx_to_offset import conllx_to_offset
@@ -31,14 +31,13 @@ class Corpus(List[Document]):
 
     @classmethod
     def read_from_file(cls, data_file):
-        with open(data_file, "rt") as fd:
-            sentence_list = read_conllx(fd)
-
         offset_data_list = []
-        for sentence in sentence_list:
-            offset_data, result = conllx_to_offset(sentence)
 
-            offset_data_list.append(offset_data)
+        with open(data_file, "rt") as fd:
+            for sentence in load_conllx(fd):
+                offset_data, result = conllx_to_offset(sentence)
+
+                offset_data_list.append(offset_data)
 
         return Corpus(offset_data_list)
 
@@ -165,6 +164,22 @@ class Corpus(List[Document]):
 
         return result
 
+    def partial_search(self, query: Union[List, tuple, str]) -> List[Tuple[Document, int]]:
+        """
+        return document and a int which represent the remain char in doc beside the query chars
+        """
+        if isinstance(query, (list, tuple)):
+            query = "".join(query)
+
+        query_len = len(query)
+        result = []
+        for doc in self:
+            doc_text = "".join(doc.text)
+            if query in doc_text:
+                result.append((doc, len(doc_text) - query_len))
+
+        return sorted(result, key=lambda x: x[1])
+
     def annotation_tags(self, scheme=None) -> List[str]:
         if scheme is not None:
             raise ValueError("scheme argument is not supported yet")
