@@ -1,4 +1,5 @@
 import copy
+from typing import List
 
 from tokenizer_tools.tagset.offset.document_compare_ways import DocumentCompareWays
 from tokenizer_tools.tagset.offset.sequence import Sequence
@@ -74,12 +75,7 @@ class Document(Sequence):
         cls = self.__class__
         doc = cls(copy.deepcopy(self.text))
 
-        attrs_need_be_copied = [
-            "domain",
-            "intent",
-            "function",
-            "sub_function",
-        ]
+        attrs_need_be_copied = ["domain", "intent", "function", "sub_function"]
 
         for attr in attrs_need_be_copied:
             setattr(doc, attr, getattr(self, attr))
@@ -90,3 +86,15 @@ class Document(Sequence):
 
     def compare_entities(self, other):
         return self.text == other.text and self.span_set == other.span_set
+
+    def entity_biluo_tags(self) -> List[str]:
+        # put import statement here for avoid circular import
+        from tokenizer_tools.tagset.NER.BILUO import BILUOEncoderDecoder
+
+        tags = ["O"] * len(self.text)
+
+        for span in self.span_set:
+            encoder = BILUOEncoderDecoder(span.entity)
+            tags[span.start : span.end] = encoder.encode(span.value)
+
+        return tags
